Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(440)

Unified Diff: runtime/vm/service_event.h

Issue 1965823002: Initial isolate reload support (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/vm/service_event.h
diff --git a/runtime/vm/service_event.h b/runtime/vm/service_event.h
index cc066761b79a981921bcfdc70725591e4a428c47..d6bc92ed24bf11535f092afb1f18c9df90e30a1d 100644
--- a/runtime/vm/service_event.h
+++ b/runtime/vm/service_event.h
@@ -24,11 +24,11 @@ class ServiceEvent {
enum EventKind {
kVMUpdate, // VM identity information has changed
- kIsolateStart, // New isolate has started
- kIsolateRunnable, // Isolate is ready to run
- kIsolateExit, // Isolate has exited
- kIsolateUpdate, // Isolate identity information has changed
-
+ kIsolateStart, // New isolate has started
+ kIsolateRunnable, // Isolate is ready to run
+ kIsolateExit, // Isolate has exited
+ kIsolateUpdate, // Isolate identity information has changed
+ kIsolateReload, // Result of a reload request
kServiceExtensionAdded, // A service extension was registered
kPauseStart, // --pause-isolates-on-start
@@ -149,6 +149,15 @@ class ServiceEvent {
exception_ = exception;
}
+ const Error* reload_error() const {
+ ASSERT(kind_ == kIsolateReload);
+ return reload_error_;
+ }
+ void set_reload_error(const Error* error) {
+ ASSERT(kind_ == kIsolateReload);
+ reload_error_ = error;
+ }
+
bool at_async_jump() const {
return at_async_jump_;
}
@@ -222,6 +231,7 @@ class ServiceEvent {
const TimelineEventBlock* timeline_event_block_;
const String* extension_rpc_;
const Object* exception_;
+ const Error* reload_error_;
bool at_async_jump_;
const Object* inspectee_;
const Heap::GCStats* gc_stats_;
« runtime/vm/object.cc ('K') | « runtime/vm/service.cc ('k') | runtime/vm/service_event.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698